@@ -236,6 +236,9 @@ class Crp:
         df_matrix = self.getTotalSpentLMonth(train_df,dateFlag_sep,df_matrix)
 
 
+        # Turn the separators into strings for the snowflake query
+        dateFlag_sep = str(dateFlag_sep)
+        date_flag_min = str(date_flag_min)
         orders_param = SQ.get_data_from_sf('V_DIFFDAYSBETWEENPURCHASESAGG',customer_name,pwd,dateFlag_sep,date_flag_min)
 
         output = pd.merge(df_matrix,orders_param,on='customerid')
